# PluginTemplate

PluginTemplate is a simple starting point for creating Spigot plugins using the **PluginKit** framework. It provides a streamlined setup to kickstart your development with pre-configured essentials.

## Features

- **Integrated with PluginKit**: Build on top of your custom PluginKit framework for consistency and reduced boilerplate.
- **Pre-configured Structure**: Includes a clear folder and package layout for your Spigot plugin.
- **Ease of Use**: Designed to get you started quickly with minimal setup.

## Requirements

- **Java 17+**
- **Spigot API**: Compatible with Spigot version 1.16 and above.
- **PluginKit Framework**: Ensure the PluginKit framework is available in your project.

## Getting Started

1. **Clone the Template**
   ```bash
   git clone https://github.com/yourusername/PluginTemplate.git
   cd PluginTemplate
   ```

2. **Set Up PluginKit**
   
    Ensure PluginKit is added as a dependency in your project. Update the pom.xml or build.gradle file if necessary.


3. **Customize Plugin Metadata**

    Update plugin.yml with your plugin's name, version, and other metadata:
    ```yaml
    name: YourPluginName
    version: '1.0-SNAPSHOT'
    main: nl.maartenvr98.YourPluginName.Main
    api-version: '1.21'
    ```

4. **Start coding**

   Use the provided structure to add commands, events, and any other logic for your plugin.


5. **Build Your Plugin**

   Use Maven or Gradle to compile your plugin:
    ```bash
    mvn clean package
    ```


6. **Test in Spigot Server**

   Copy the JAR file into your Spigot server's plugins folder and start the server.


## File Structure
```plaintext
PluginTemplate/
├── src/
│   ├── main/
│   │   ├── java/
│   │   │   └── nl/maartenvr98/YourPluginName
│   │   │       ├── commands/
│   │   │       │   └── MyCommand.java
│   │   │       ├── listener/
│   │   │       │   └── PlayerListener.java
│   │   │       ├── config/
│   │   │       │   └── MainConfig.java
│   │   │       └── Main.java
│   │   ├── resources/
│   │   │   ├── plugin.yml
├── pom.xml
└── README.md
```


## Contributing
Contributions are welcome! Feel free to open issues or submit pull requests to improve the template


## License
This project is licensed under the MIT License.